# pyBot
Impelementations of famous robotics algorithms 

## Projects Planned

### Planners

- [ ] Breath First Search            
- [ ] Dijkstra algorithm                            
- [ ] A* algorithm            
- [ ] D* algorithm            
- [ ] Potential Field algorithm            
- [ ] RRT            
- [ ] RRT*            
- [ ] LQR-RRT*            
- [ ] LQR based path planning            
    

### Environments
- [ ] 2D             
- [ ] 3D 
